summaryrefslogtreecommitdiff
path: root/framework/Web/UI/WebControls/TBaseValidator.php
diff options
context:
space:
mode:
Diffstat (limited to 'framework/Web/UI/WebControls/TBaseValidator.php')
-rw-r--r--framework/Web/UI/WebControls/TBaseValidator.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/framework/Web/UI/WebControls/TBaseValidator.php b/framework/Web/UI/WebControls/TBaseValidator.php
index 5110230b..eeb5d0e8 100644
--- a/framework/Web/UI/WebControls/TBaseValidator.php
+++ b/framework/Web/UI/WebControls/TBaseValidator.php
@@ -180,13 +180,13 @@ abstract class TBaseValidator extends TLabel implements IValidator
}
/**
* This method overrides the parent implementation to forbid setting AssociatedControlID.
* @param string the associated control ID
* @throws TNotSupportedException whenever this method is called
*/
- public function setAssociatedControlID($value)
+ public function setForControl($value)
{
- throw new TNotSupportedException('basevalidator_associatedcontrolid_unsupported',get_class($this));
+ throw new TNotSupportedException('basevalidator_forcontrol_unsupported',get_class($this));
}
/**
@@ -180,13 +180,13 @@ abstract class TBaseValidator extends TLabel implements IValidator
}
/**
- * This method overrides the parent implementation to forbid setting AssociatedControlID.
+ * This method overrides the parent implementation to forbid setting ForControl.
* @param string the associated control ID
* @throws TNotSupportedException whenever this method is called